@@ -2,7 +2,7 @@
 #
 # Another example to install one or more (source) packages into a drat
 #
-# Copyright (C) 2015  Dirk Eddelbuettel
+# Copyright (C) 2015 - 2016  Dirk Eddelbuettel
 #
 # Released under GPL (>= 2)
 
@@ -11,19 +11,25 @@ suppressMessages(library(docopt))       # we need docopt (>= 0.3) as on CRAN
 suppressMessages(library(drat))     
 
 ## configuration for docopt
-doc <- "Usage: drat.r [-h] [--repo REPO] [--commit MSG] TARGZ...
+doc <- "Usage: drat.r [-h] [-x] [--repo REPO] [--commit MSG] [TARGZ...]
 
--r --repo REPO      repository path to use [default: ~/git/drat]
--c --commit MSG     in github use, commit with MSG (default: no commit)
--h --help           show this help text
+-r --repo REPO        repository path to use [default: ~/git/drat]
+-c --commit MSG       in github use, commit with MSG (default: no commit)
+-h --help             show this help text
+-x --usage            show help and short example usage"
 
-Examples:
+opt <- docopt(doc)			# docopt parsing
+
+if (opt$usage) {
+    cat(doc, "\n\n")
+    cat("Examples:
   dratInsert.r myPkg_1.2-3.tar.gz              # installs into default (git) repo
   dratInsert.r -r /srv/R/  myPkg_1.2-3.tar.gz  # installs into local directory repo
 
-dratInstert.r is part of littler which brings 'r' to the command-line.
-See http://dirk.eddelbuettel.com/code/littler.html for more information.
-"
+dratInsert.r is part of littler which brings 'r' to the command-line.
+See http://dirk.eddelbuettel.com/code/littler.html for more information.\n")
+    q("no")
+}
 
 ## docopt parsing
 opt <- docopt(doc)
